@@ -1,6 +1,6 @@
 #[macro_use]
 pub mod log;
-pub mod bytemerge;
+pub mod int;
 pub mod result;
 
 #[cfg(test)]
