@@ -1,4 +1,4 @@
-use super::bytemerge;
+use super::int;
 use super::log;
 use super::result;
 
@@ -46,9 +46,9 @@ fn test_result() {
 #[test]
 fn test_bytemerge() {
     assert_eq!(
-        bytemerge::bytemerge(&[0xFF, 0xFF, 0xFF, 0xFF]).unwrap(),
+        int::deserialize(&[0xFF, 0xFF, 0xFF, 0xFF]).unwrap(),
         0xFFFFFFFF
     );
 
-    assert_eq!(bytemerge::bytemerge(&[0xFF, 0xFF]).unwrap(), 0xFFFF);
+    assert_eq!(int::deserialize(&[0xFF, 0xFF]).unwrap(), 0xFFFF);
 }
